This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-beanutils.git


The following commit(s) were added to refs/heads/master by this push:
     new 4d5fac3  Spell as 'writable'.
4d5fac3 is described below

commit 4d5fac3537a3ecc879ddf8884ae9cbeb92562a67
Author: Gary Gregory <[email protected]>
AuthorDate: Sat Jul 10 09:08:14 2021 -0400

    Spell as 'writable'.
---
 src/main/java/org/apache/commons/beanutils2/LazyDynaClass.java    | 8 ++++----
 src/main/java/org/apache/commons/beanutils2/LazyDynaMap.java      | 8 ++++----
 src/main/java/org/apache/commons/beanutils2/MutableDynaClass.java | 6 +++---
 src/main/java/org/apache/commons/beanutils2/PropertyUtils.java    | 4 ++--
 .../java/org/apache/commons/beanutils2/PropertyUtilsBean.java     | 6 +++---
 5 files changed, 16 insertions(+), 16 deletions(-)

diff --git a/src/main/java/org/apache/commons/beanutils2/LazyDynaClass.java 
b/src/main/java/org/apache/commons/beanutils2/LazyDynaClass.java
index 8f5c64b..105bdaf 100644
--- a/src/main/java/org/apache/commons/beanutils2/LazyDynaClass.java
+++ b/src/main/java/org/apache/commons/beanutils2/LazyDynaClass.java
@@ -194,7 +194,7 @@ public class LazyDynaClass extends BasicDynaClass 
implements MutableDynaClass  {
      * <p>Add a new dynamic property with the specified data type, readability,
      * and writeability.</p>
      *
-     * <p><strong>N.B.</strong>Support for readable/writeable properties has 
not been implemented
+     * <p><strong>N.B.</strong>Support for readable/writable properties has 
not been implemented
      *    and this method always throws a {@code 
UnsupportedOperationException}.</p>
      *
      * <p>I'm not sure the intention of the original authors for this method, 
but it seems to
@@ -206,13 +206,13 @@ public class LazyDynaClass extends BasicDynaClass 
implements MutableDynaClass  {
      *  restrictions)
      * @param readable Set to {@code true} if this property value
      *  should be readable
-     * @param writeable Set to {@code true} if this property value
-     *  should be writeable
+     * @param writable Set to {@code true} if this property value
+     *  should be writable
      *
      * @throws UnsupportedOperationException anytime this method is called
      */
     @Override
-    public void add(final String name, final Class<?> type, final boolean 
readable, final boolean writeable) {
+    public void add(final String name, final Class<?> type, final boolean 
readable, final boolean writable) {
         throw new java.lang.UnsupportedOperationException("readable/writable 
properties not supported");
     }
 
diff --git a/src/main/java/org/apache/commons/beanutils2/LazyDynaMap.java 
b/src/main/java/org/apache/commons/beanutils2/LazyDynaMap.java
index 078407e..a5ad3dd 100644
--- a/src/main/java/org/apache/commons/beanutils2/LazyDynaMap.java
+++ b/src/main/java/org/apache/commons/beanutils2/LazyDynaMap.java
@@ -370,7 +370,7 @@ public class LazyDynaMap extends LazyDynaBean implements 
MutableDynaClass {
      * <p>Add a new dynamic property with the specified data type, readability,
      * and writeability.</p>
      *
-     * <p><strong>N.B.</strong>Support for readable/writeable properties has 
not been implemented
+     * <p><strong>N.B.</strong>Support for readable/writable properties has 
not been implemented
      *    and this method always throws a {@code 
UnsupportedOperationException}.</p>
      *
      * <p>I'm not sure the intention of the original authors for this method, 
but it seems to
@@ -382,13 +382,13 @@ public class LazyDynaMap extends LazyDynaBean implements 
MutableDynaClass {
      *  restrictions)
      * @param readable Set to {@code true} if this property value
      *  should be readable
-     * @param writeable Set to {@code true} if this property value
-     *  should be writeable
+     * @param writable Set to {@code true} if this property value
+     *  should be writable
      *
      * @throws UnsupportedOperationException anytime this method is called
      */
     @Override
-    public void add(final String name, final Class<?> type, final boolean 
readable, final boolean writeable) {
+    public void add(final String name, final Class<?> type, final boolean 
readable, final boolean writable) {
         throw new java.lang.UnsupportedOperationException("readable/writable 
properties not supported");
     }
 
diff --git a/src/main/java/org/apache/commons/beanutils2/PropertyUtils.java 
b/src/main/java/org/apache/commons/beanutils2/PropertyUtils.java
index a64f44e..16ccf52 100644
--- a/src/main/java/org/apache/commons/beanutils2/PropertyUtils.java
+++ b/src/main/java/org/apache/commons/beanutils2/PropertyUtils.java
@@ -568,14 +568,14 @@ public class PropertyUtils {
 
     /**
      * <p>Return {@code true} if the specified property name identifies
-     * a writeable property on the specified bean; otherwise, return
+     * a writable property on the specified bean; otherwise, return
      * {@code false}.</p>
      *
      * <p>For more details see {@code PropertyUtilsBean}.</p>
      *
      * @param bean Bean to be examined (may be a {@link DynaBean}
      * @param name Property name to be evaluated
-     * @return {@code true} if the property is writeable,
+     * @return {@code true} if the property is writable,
      * otherwise {@code false}
      *
      * @throws IllegalArgumentException if {@code bean}
diff --git a/src/main/java/org/apache/commons/beanutils2/PropertyUtilsBean.java 
b/src/main/java/org/apache/commons/beanutils2/PropertyUtilsBean.java
index 4628ffb..cfedff4 100644
--- a/src/main/java/org/apache/commons/beanutils2/PropertyUtilsBean.java
+++ b/src/main/java/org/apache/commons/beanutils2/PropertyUtilsBean.java
@@ -1361,12 +1361,12 @@ public class PropertyUtilsBean {
 
     /**
      * <p>Return {@code true} if the specified property name identifies
-     * a writeable property on the specified bean; otherwise, return
+     * a writable property on the specified bean; otherwise, return
      * {@code false}.
      *
      * @param bean Bean to be examined (may be a {@link DynaBean}
      * @param name Property name to be evaluated
-     * @return {@code true} if the property is writeable,
+     * @return {@code true} if the property is writable,
      * otherwise {@code false}
      *
      * @throws IllegalArgumentException if {@code bean}
@@ -1414,7 +1414,7 @@ public class PropertyUtilsBean {
 
         // Return the requested result
         if (bean instanceof DynaBean) {
-            // All DynaBean properties are writeable
+            // All DynaBean properties are writable
             return ((DynaBean) bean).getDynaClass().getDynaProperty(name) != 
null;
         }
         try {

Reply via email to
diff --git a/src/main/java/org/apache/commons/beanutils2/MutableDynaClass.java 
b/src/main/java/org/apache/commons/beanutils2/MutableDynaClass.java
index c2108c7..241d725 100644
--- a/src/main/java/org/apache/commons/beanutils2/MutableDynaClass.java
+++ b/src/main/java/org/apache/commons/beanutils2/MutableDynaClass.java
@@ -64,15 +64,15 @@ public interface MutableDynaClass extends DynaClass {
      *  restrictions)
      * @param readable Set to {@code true} if this property value
      *  should be readable
      * @param writeable Set to {@code true} if this property value
      *  should be writeable
      *
      * @throws IllegalArgumentException if name is null
      * @throws IllegalStateException if this DynaClass is currently
      *  restricted, so no new properties can be added
      */
     void add(String name, Class<?> type, boolean readable,
-             boolean writeable);
+             boolean writable);
 
     /**
      * Is this DynaClass currently restricted, if so, no changes to the
@@ -64,15 +64,15 @@ public interface MutableDynaClass extends DynaClass {
      * @param readable Set to {@code true} if this property value
      *  should be readable
-     * @param writeable Set to {@code true} if this property value
-     *  should be writeable
+     * @param writable Set to {@code true} if this property value
+     *  should be writable
      *
      * @throws IllegalArgumentException if name is null